@@ -1,5 +1,4 @@
 import logging
-import pathlib
 from collections import defaultdict
 from typing import Any, DefaultDict, Dict, List, Set, Tuple
 
@@ -19,8 +18,6 @@ from transformers import AutoTokenizer
 
 logger = logging.getLogger(__name__)
 
-FRAME_LIST_PATH = pathlib.Path(__file__).resolve().parent / "resources" / "framelist.txt"
-
 
 def _convert_verb_indices_to_wordpiece_indices(
     verb_indices: List[int], offsets: List[int], binary: bool = True
@@ -468,7 +465,10 @@ class SrlUdpDatasetReader(SrlTransformersSpanReader):
                 # transpose rolses, to have a list of roles per frame
                 roles = list(map(list, zip(*roles)))
                 current_frame = 0
-                for i, frame, in enumerate(frames):
+                for (
+                    i,
+                    frame,
+                ) in enumerate(frames):
                     if frame != "_":
                         verb_indicator = [0] * len(frames)
                         verb_indicator[i] = 1
